@@ -1,18 +1,9 @@
 import json
 import requests
 
+import openai
 import openai_proxy
-from openai_proxy.utils import token_estimator
-
-
-def authenticate():
-    # TODO: Authorize public users
-    if openai_proxy.username == "" or openai_proxy.username is None \
-            or openai_proxy.course_id == "" or openai_proxy.course_id is None \
-            or openai_proxy.access_key == "" or openai_proxy.access_key is None \
-            or openai_proxy.access_token == "" or openai_proxy.access_token is None:
-        return "Please set your username, courseId, accessKey, and accessToken"
-    return False
+from openai_proxy.utils import token_estimator, auth
 
 
 class Completion:
@@ -27,15 +18,11 @@ class Completion:
                stop='',
                n=1
                ):
-        error = authenticate()
-        if error:
-            return error
+        authentication = auth.authenticate()
+        if authentication == auth.AuthStatus.ERROR:
+            return "Please set your username, courseId, accessKey, and accessToken or just your OpenAI API key"
 
-        body = {
-            "username": openai_proxy.username,
-            "courseId": openai_proxy.course_id,
-            "accessKey": openai_proxy.access_key,
-            "accessToken": openai_proxy.access_token,
+        params = {
             "prompt": prompt,
             "max_tokens": max_tokens,
             "engine": engine,
@@ -46,7 +33,18 @@ class Completion:
             "stop": stop,
             "n": n
         }
-        r = requests.post('http://openai-proxy.herokuapp.com/b/request/openai/completion', json=body)
+
+        if authentication == auth.AuthStatus.PUBLIC:
+            openai.api_key = openai_proxy.api_key
+            response = openai.Completion.create(**params)
+            response["price"] = token_estimator.price_calculator_completion(params)
+            return response
+
+        params["username"] = openai_proxy.username
+        params["courseId"] = openai_proxy.course_id
+        params["accessKey"] = openai_proxy.access_key
+        params["accessToken"] = openai_proxy.access_token
+        r = requests.post('http://openai-proxy.herokuapp.com/b/request/openai/completion', json=params)
         response = json.loads(r.text)
         if response['status'] == 'success':
             return response['response']
