@@ -1,18 +1,31 @@
-from transformers import GPT2TokenizerFast
-from openai_proxy.utils.constants import price_per_token, engine_max_tokens, get_price_per_token, get_engine_max_tokens
+import tiktoken
+from openai_proxy.utils.constants import get_price_per_token, get_engine_max_tokens
 
 
-def token_counter(prompt):
+def token_counter(prompt, model):
+    # TODO: Does not properly support key "name" in chat models
     # counts tokens given input text
     #
     # input: text
     # output: length of tokens
-    tokenizer = GPT2TokenizerFast.from_pretrained("gpt2")
-    token_len = len(tokenizer(prompt)['input_ids'])
+
+    encoder = tiktoken.encoding_for_model(model) if model else tiktoken.get_encoding("cl100k_base")
+    token_len = len(encoder.encode(prompt))
 
     return token_len
 
 
+def get_message_padding(model):
+    message_padding = 0
+    if not model:
+        pass
+    elif model == "gpt-4":
+        message_padding = 3
+    elif model == "gpt-3.5-turbo":
+        message_padding = 4
+    return message_padding
+
+
 def parse_args(args):
     prompt = args['prompt'] if 'prompt' in args else ''
     engine = args['engine'] if 'engine' in args else 'babbage'
@@ -48,7 +61,7 @@ def price_calculator_completion(args):
     n = p_args['n']
     total_tokens = p_args['total_tokens']
 
-    token_len = token_counter(prompt)
+    token_len = token_counter(prompt, engine)
     this_engine_max_tokens = get_engine_max_tokens(engine)
     this_price_per_token = get_price_per_token(engine)
 
@@ -71,21 +84,39 @@ def price_calculator_completion(args):
     return round(price, 10)
 
 
-def price_calculator_chat(messages):
-    cost = 0
-    if 'total_tokens' in messages:
-        cost = messages['total_tokens'] * get_price_per_token('gpt-3.5-turbo')
-        return round(cost, 10)
+def price_calculator_chat(messages, model='gpt-3.5-turbo'):
+    prompt_cost = 0
+    completion_cost = 0
 
+    # Pre-request estimation with max_tokens
+    prompt_tokens = 0
     for message in messages:
-        token_len = token_counter(message["content"])
-        cost += token_len * get_price_per_token('gpt-3.5-turbo')
-    return round(cost, 10)
+        token_len = token_counter(message["content"], model) + \
+                    token_counter(message["role"], model) + \
+                    get_message_padding(model)
+        prompt_tokens += token_len
+        prompt_cost += token_len * get_price_per_token(model + "-prompt")
+    completion_cost += (get_engine_max_tokens(model) - prompt_tokens) * \
+                       get_price_per_token(model + "-completion")
+    return round(prompt_cost + completion_cost, 10)
+
+
+def price_calculator_chat_completion(usage, model='gpt-3.5-turbo'):
+    return round(usage["prompt_tokens"] * get_price_per_token(model + "-prompt") +
+                 usage["completion_tokens"] * get_price_per_token(model + "-completion")
+                 , 10)
 
 
 def price_calculator_embedding(phrases):
+    model = 'text-embedding-ada-002'
     cost = 0
     for phrase in phrases:
-        token_len = token_counter(phrase)
-        cost += token_len * get_price_per_token('text-embedding-ada-002')
+        token_len = token_counter(phrase, model)
+        cost += token_len * get_price_per_token(model)
     return round(cost, 10)
+
+
+def price_calculator_image(args):
+    n = args['n'] if 'n' in args else 1
+    size = args['size'] if 'size' in args else "1024x1024"
+    return round(n * get_price_per_token(size), 10)
